<?php

declare(strict_types=1);
// ----------------------------------------------------------------------------------------------------
// - Display Errors
// ----------------------------------------------------------------------------------------------------
// ini_set('display_errors', '1');

// ----------------------------------------------------------------------------------------------------
// - Error Reporting
// ----------------------------------------------------------------------------------------------------
error_reporting(\E_ALL);

// ----------------------------------------------------------------------------------------------------
// - Shutdown Handler
// ----------------------------------------------------------------------------------------------------
if ( ! \function_exists('ShutdownHandler')) {
  function ShutdownHandler()
  {
    if (@\is_array($error = @error_get_last())) {
      return @ErrorHandler(...array_values($error));
    }

    return true;
  }

  register_shutdown_function('ShutdownHandler');
}
// ----------------------------------------------------------------------------------------------------
// - Error Handler
// ----------------------------------------------------------------------------------------------------
if ( ! \function_exists('ErrorHandler')) {
  function ErrorHandler($type, $message, $file, $line)
  {
    $_ERRORS = [
      0x0001 => 'E_ERROR',
      0x0002 => 'E_WARNING',
      0x0004 => 'E_PARSE',
      0x0010 => 'E_CORE_ERROR',
      0x0020 => 'E_CORE_WARNING',
      0x0040 => 'E_COMPILE_ERROR',
      0x0080 => 'E_COMPILE_WARNING',
      0x0100 => 'E_USER_ERROR',
      0x0200 => 'E_USER_WARNING',
      0x0400 => 'E_USER_NOTICE',
      0x0800 => 'E_STRICT',
      0x1000 => 'E_RECOVERABLE_ERROR',
      0x2000 => 'E_DEPRECATED',
      0x4000 => 'E_USER_DEPRECATED',
    ];

    $_DONTCARE = [
      // 0x0008 => 'E_NOTICE',
      0x2000 => 'E_DEPRECATED',
    ];

    if (@\is_string($name = @array_search($type, @array_flip($_DONTCARE), true))) {
      return;
    }

    if ( ! @\is_string($name = @array_search($type, @array_flip($_ERRORS), true))) {
      $name = 'E_UNKNOWN';
    }

    return print @sprintf("<b>DEV ERROR:</b> %s Error in file „%s“ at line %d: <pre>%s</pre><br />\n", $name, @basename($file), $line, $message);
  }
  $old_error_handler = set_error_handler('ErrorHandler');
}
